@@ -64,14 +64,16 @@ rose.grob <- function(rho,
                          r = grid$circ$sub$r[grid$circ$sub$r>0],
                          default.units = "native",
                          gp=gpar(col = grid$circ$sub$col,
-                         lwd = grid$circ$sub$lwd)),
+                                 fill="transparent",
+                                 lwd = grid$circ$sub$lwd)),
 
               circleGrob(name = "circles",
                          x = 0, y = 0,
                          r = grid$circ$r[grid$circ$r>0],
                          default.units = "native",
                          gp = gpar(col = grid$circ$col,
-                         lwd = grid$circ$lwd)),
+                                   fill="transparent",
+                                   lwd = grid$circ$lwd)),
 
               textGrob(name = "circ.lab",
                        grid$circ$value,
@@ -79,7 +81,8 @@ rose.grob <- function(rho,
                        y = gdat$circ$lab$y,
                        just = c("center","center"),
                        default.units = "native",
-                       gp = gpar(cex=grid$circ$cex)),
+                       gp = gpar(cex=grid$circ$cex,
+                                 fill="transparent")),
 
               segmentsGrob(name = "rays",
                            x0 = 0, y0 = 0,
@@ -89,7 +92,8 @@ rose.grob <- function(rho,
                            cos(2*pi/grid$ray$n*(1:grid$ray$n)),
                            default.units = "native",
                            gp=gpar(col=grid$circ$col,
-                           lwd=grid$circ$lwd)),
+                                   fill="transparent",
+                                   lwd=grid$circ$lwd)),
 
               textGrob(name = "cyclVar.lab",
                        label = grid$cyclVar$lab,
@@ -97,7 +101,8 @@ rose.grob <- function(rho,
                        y = gdat$cyclVar$lab$y,
                        default.units = "native",
                        just = c("center","center"),
-                       gp=gpar(cex = grid$cyclVar$cex)),
+                       gp=gpar(cex = grid$cyclVar$cex,
+                               fill="transparent")),
 
               if (!is.null(title$text))
               textGrob(name = "title",
@@ -106,6 +111,7 @@ rose.grob <- function(rho,
                        y = gdat$title$y,
                        default.units = "native",
                        just = c("center","bottom"),
-                       gp = gpar(cex=title$cex))))
+                       gp = gpar(cex=title$cex,
+                                 fill="transparent"))))
     return(rose)
 } ## rose.grob
